Core
======

Aggregation
-----------
.. automodule:: bamboo.core.aggregations
    :members:

Aggregator
----------
.. autoclass:: bamboo.core.aggregator.Aggregator
    :members:

Calculator
----------
.. autoclass:: bamboo.core.calculator.Calculator
    :members:
    :private-members:

Frame
-----
.. automodule:: bamboo.core.frame
    :members:

Merge
-----
.. automodule:: bamboo.core.merge
    :members:

Parsing Operations
------------------
.. automodule:: bamboo.core.operations
    :members:

Formula Parser
--------------
.. autoclass:: bamboo.core.parser.Parser
    :members:
    :private-members:

Summary Statistic Utilities
---------------------------
.. automodule:: bamboo.core.summary
    :members:
